[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,69 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/graph/graph_ctx.cuh>
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
template <typename S>
|
||||
__global__ void inc_kernel(S sA)
|
||||
{
|
||||
sA(threadIdx.x)++;
|
||||
}
|
||||
|
||||
template <typename S1, typename S2>
|
||||
__global__ void copy_kernel(S1 sA, S2 sB)
|
||||
{
|
||||
sB(threadIdx.x) = sA(threadIdx.x);
|
||||
}
|
||||
|
||||
template <typename Ctx>
|
||||
void run()
|
||||
{
|
||||
int A[10] = {0};
|
||||
int B[10] = {0};
|
||||
Ctx ctx;
|
||||
|
||||
auto lA = ctx.logical_data(A);
|
||||
auto lB = ctx.logical_data(B);
|
||||
|
||||
for (size_t k = 0; k < 10; k++)
|
||||
{
|
||||
// fprintf(stderr, "iter %zu - 0 : ctx.hash %zu\n", k, ctx.hash());
|
||||
ctx.task(lA.rw())->*[](cudaStream_t stream, auto sA) {
|
||||
inc_kernel<<<1, 10, 0, stream>>>(sA);
|
||||
};
|
||||
|
||||
// fprintf(stderr, "iter %zu - 1 : ctx.hash %zu\n", k, ctx.hash());
|
||||
ctx.task(lA.read(), lB.rw())->*[](cudaStream_t stream, auto sA, auto sB) {
|
||||
copy_kernel<<<1, 10, 0, stream>>>(sA, sB);
|
||||
};
|
||||
|
||||
// fprintf(stderr, "iter %zu - 2 : ctx.hash %zu\n", k, ctx.hash());
|
||||
ctx.task(lB.rw())->*[](cudaStream_t stream, auto sB) {
|
||||
inc_kernel<<<1, 10, 0, stream>>>(sB);
|
||||
};
|
||||
|
||||
// fprintf(stderr, "iter %zu - 3 : ctx.hash %zu\n", k, ctx.hash());
|
||||
}
|
||||
|
||||
ctx.host_launch(lA.read(), lB.read())->*[&](auto /*unused*/, auto /*unused*/) {
|
||||
// fprintf(stderr, "HOST END : ctx.hash %zu\n", ctx.hash());
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
run<stream_ctx>();
|
||||
run<graph_ctx>();
|
||||
}
|
||||
@@ -1,51 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/graph/graph_ctx.cuh>
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
template <typename S>
|
||||
__global__ void inc_kernel(S sA)
|
||||
{
|
||||
sA(threadIdx.x)++;
|
||||
}
|
||||
|
||||
template <typename Ctx>
|
||||
void run()
|
||||
{
|
||||
int A[10] = {0};
|
||||
stream_ctx ctx;
|
||||
|
||||
auto l = ctx.logical_data(A);
|
||||
|
||||
for (size_t k = 0; k < 10; k++)
|
||||
{
|
||||
// size_t h = l.hash();
|
||||
// fprintf(stderr, "iter %zu : logical data hash %zu ctx.hash %zu\n", k, h, ctx.hash());
|
||||
|
||||
ctx.task(l.rw())->*[](cudaStream_t stream, auto sA) {
|
||||
inc_kernel<<<1, 10, 0, stream>>>(sA);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.host_launch(l.read())->*[&](auto /*unused*/) {
|
||||
// fprintf(stderr, "HOST end : logical data hash %zu ctx.hash %zu\n", l.hash(), ctx.hash());
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
run<stream_ctx>();
|
||||
run<graph_ctx>();
|
||||
}
|
||||
Reference in New Issue
Block a user